@@ -1,5 +1,6 @@
 import numpy as np
 from moviepy.decorators import apply_to_mask
+from moviepy.video.VideoClip import ImageClip
 
 
 @apply_to_mask
@@ -26,19 +27,31 @@ def margin(clip, mar=None, left=0, right=0, top=0,
 
     if mar != None:
         left = right = top = bottom = mar
-
-    new_w, new_h = clip.w + left + right, clip.h + top + bottom
     
-    if clip.ismask:
-        shape = (new_h, new_w)
-        bg = np.tile(opacity, (new_h, new_w)).reshape(shape)
+    def make_bg(w,h):
+        new_w, new_h = w + left + right, h + top + bottom
+        if clip.ismask:
+            shape = (new_h, new_w)
+            bg = np.tile(opacity, (new_h, new_w)).reshape(shape)
+        else:
+            shape = (new_h, new_w, 3)
+            bg = np.tile(color, (new_h, new_w)).reshape(shape)
+        return bg
+        
+    if isinstance(clip, ImageClip):
+        
+        im =  make_bg(clip.w,clip.h)
+        im[top:top + clip.h, left:left + clip.w] = clip.img
+        return clip.fl_image(lambda pic:im)
+        
     else:
-        shape = (new_h, new_w, 3)
-        bg = np.tile(color, (new_h, new_w)).reshape(shape)
-
-    def fl(pic):
-        im = +bg
-        im[top:top + clip.h, left:left + clip.w] = pic
-        return im
-
-    return clip.fl_image(fl)
+        
+        def fl(gf, t):
+            pic = gf(t)
+            h,w = pic.shape[:2]
+            im = make_bg(w,h)
+            im[top:top + h, left:left + w] = pic
+            return im
+        return clip.fl(fl)
+            
+    
